From d707aa669e533cdc870f05fec889953bee10178b Mon Sep 17 00:00:00 2001
From: Sumit Garg <sumit.garg@nxp.com>
Date: Wed, 4 May 2016 11:55:28 -0400
Subject: [PATCH 1/4] plat-ls: Override generic init_sec_mon

Override generic init_sec_mon by plat-ls/main.c to restore spsr along
with NS entry for initial return to non-secure world for this platform.

Signed-off-by: Sumit Garg <sumit.garg@nxp.com>
---
 core/arch/arm/plat-ls/main.c | 23 +++++++++++++++++++++++
 1 file changed, 23 insertions(+)

diff --git a/core/arch/arm/plat-ls/main.c b/core/arch/arm/plat-ls/main.c
index a92f63a..7588402 100644
--- a/core/arch/arm/plat-ls/main.c
+++ b/core/arch/arm/plat-ls/main.c
@@ -33,8 +33,10 @@
 #include <kernel/thread.h>
 #include <kernel/panic.h>
 #include <kernel/pm_stubs.h>
+#include <mm/core_mmu.h>
 #include <tee/entry_std.h>
 #include <tee/entry_fast.h>
+#include <sm/sm.h>
 
 static void main_fiq(void);
 
@@ -55,11 +57,32 @@ const struct thread_handlers *generic_boot_get_handlers(void)
 	return &handlers;
 }
 
+struct plat_nsec_ctx {
+	uint32_t mon_lr;
+	uint32_t mon_spsr;
+};
+
 static void main_fiq(void)
 {
 	panic();
 }
 
+void init_sec_mon(uint32_t nsec_entry)
+{
+	struct plat_nsec_ctx *plat_ctx = (struct plat_nsec_ctx *)nsec_entry;
+	struct sm_nsec_ctx *nsec_ctx;
+
+	/* Invalidate cache to fetch data from external memory */
+	cache_maintenance_l1(DCACHE_AREA_INVALIDATE, (void *)nsec_entry,
+			     sizeof(struct plat_nsec_ctx));
+
+	/* Initialize secure monitor */
+	nsec_ctx = sm_get_nsec_ctx();
+
+	nsec_ctx->mon_lr = plat_ctx->mon_lr;
+	nsec_ctx->mon_spsr = plat_ctx->mon_spsr;
+}
+
 void console_init(void)
 {
 	/*
-- 
1.8.1.4

